@@ -1,6 +1,7 @@
 """comet_maths - Mathematical algorithms and tools to use within CoMet toolkit."""
 from comet_maths.random.generate_sample import (
     generate_sample,
+    generate_error_sample,
     generate_sample_systematic,
     generate_sample_random,
     generate_sample_cov,
@@ -34,7 +35,4 @@ from comet_maths.interpolation.interpolation import (
 __author__ = "Pieter De Vis <pieter.de.vis@npl.co.uk>"
 __all__ = []
 
-from ._version import get_versions
-
-__version__ = get_versions()["version"]
-del get_versions
+from ._version import __version__
